@@ -1,11 +1,11 @@
 package Net::DNS;
 
 #
-# $Id: DNS.pm 1231 2014-07-10 09:12:57Z willem $
+# $Id: DNS.pm 1285 2014-10-29 13:31:41Z willem $
 #
 use vars qw($VERSION $SVNVERSION);
-$VERSION    = '0.78';
-$SVNVERSION = (qw$LastChangedRevision: 1231 $)[1];
+$VERSION    = '0.81';
+$SVNVERSION = (qw$LastChangedRevision: 1285 $)[1];
 
 
 =head1 NAME
@@ -196,18 +196,16 @@ if (OLDDNSSEC) {
 		new Net::DNS::RR( type => $type );
 	}
 
-	eval {
+	eval <<EOT;
 		no warnings 'void';	## suppress "Too late to run INIT block ..."
 
-		sub INIT {		## only needed to satisfy DNSSEC t/00-load.t
-			return unless OLDDNSSEC;
-
-			# attempt to pre-load RRs which have circular dependence problems
-			foreach my $type (qw(NSEC3 NSEC3PARAM)) {
-				new Net::DNS::RR( type => $type );
-			}
+		sub INIT {
+			# deferred pre-load of RRs with intractable dependence problems
+			# required to satisfy Net::DNS::SEC t/00-load.t
+			new Net::DNS::RR( type => 'NSEC3' );
+			new Net::DNS::RR( type => 'NSEC3PARAM' );
 		}
-	};
+EOT
 }
 
 
@@ -338,68 +336,63 @@ __END__
 
 =head2 Resolver Objects
 
-A resolver object is an instance of the
-L<Net::DNS::Resolver|Net::DNS::Resolver> class. A program can have
-multiple resolver objects, each maintaining its own state information
-such as the nameservers to be queried, whether recursion is desired,
-etc.
+A resolver object is an instance of the L<Net::DNS::Resolver> class.
+A program can have multiple resolver objects, each maintaining its
+own state information such as the nameservers to be queried, whether
+recursion is desired, etc.
 
 
 =head2 Packet Objects
 
-L<Net::DNS::Resolver|Net::DNS::Resolver> queries return
-L<Net::DNS::Packet|Net::DNS::Packet> objects.  Packet objects have five
-sections:
+L<Net::DNS::Resolver> queries return L<Net::DNS::Packet> objects.
+Packet objects have five sections:
 
 =over 3
 
 =item *
 
-The header section, a L<Net::DNS::Header|Net::DNS::Header> object.
+The header section, a L<Net::DNS::Header> object.
 
 =item *
 
-The question section, a list of L<Net::DNS::Question|Net::DNS::Question>
-objects.
+The question section, a list of L<Net::DNS::Question> objects.
 
 =item *
 
-The answer section, a list of L<Net::DNS::RR|Net::DNS::RR> objects.
+The answer section, a list of L<Net::DNS::RR> objects.
 
 =item *
 
-The authority section, a list of L<Net::DNS::RR|Net::DNS::RR> objects.
+The authority section, a list of L<Net::DNS::RR> objects.
 
 =item *
 
-The additional section, a list of L<Net::DNS::RR|Net::DNS::RR> objects.
+The additional section, a list of L<Net::DNS::RR> objects.
 
 =back
 
 =head2 Update Objects
 
-The L<Net::DNS::Update|Net::DNS::Update> package is a subclass of
-L<Net::DNS::Packet|Net::DNS::Packet> for creating packet objects to be
-used in dynamic updates.
+L<Net::DNS::Update> is a subclass of L<Net::DNS::Packet>
+used to create dynamic update requests.
 
 =head2 Header Objects
 
-L<Net::DNS::Header|Net::DNS::Header> objects represent the header
+L<Net::DNS::Header> objects represent the header
 section of a DNS packet.
 
 =head2 Question Objects
 
-L<Net::DNS::Question|Net::DNS::Question> objects represent the content
-of the question section of a DNS packet.
+L<Net::DNS::Question> objects represent the content of the question
+section of a DNS packet.
 
 =head2 RR Objects
 
-L<Net::DNS::RR|Net::DNS::RR> is the base class for DNS resource record
-(RR) objects in the answer, authority, and additional sections of a DNS
-packet.
+L<Net::DNS::RR> is the base class for DNS resource record (RR) objects
+in the answer, authority, and additional sections of a DNS packet.
 
-Do not assume that RR objects will be of the type you requested -- always
-check the type of an RR object before calling any of its methods.
+Do not assume that RR objects will be of the type requested.
+The type of an RR object must be checked before calling any methods.
 
 
 =head1 METHODS
@@ -414,7 +407,7 @@ Returns the version of Net::DNS.
 
 =head2 mx
 
-    # Use a default resolver -- can't get an error string this way.
+    # Use a default resolver -- can not get an error string this way.
     use Net::DNS;
     my @mx = mx("example.com");
 
@@ -423,12 +416,12 @@ Returns the version of Net::DNS.
     my $res = Net::DNS::Resolver->new;
     my @mx = mx($res, "example.com");
 
-Returns a list of L<Net::DNS::RR::MX|Net::DNS::RR::MX> objects
-representing the MX records for the specified name; the list will be
-sorted by preference. Returns an empty list if the query failed or no MX
-records were found.
+Returns a list of L<Net::DNS::RR::MX> objects representing the MX
+records for the specified name.
+The list will be sorted by preference.
+Returns an empty list if the query failed or no MX record was found.
 
-This method does not look up A records -- it only performs MX queries.
+This method does not look up A records; it only performs MX queries.
 
 See L</EXAMPLES> for a more complete example.
 
@@ -457,7 +450,7 @@ exist.
 Meaning:  At least one RR with the specified name and type must
 exist and must have matching data.
 
-Returns a C<Net::DNS::RR> object or C<undef> if the object couldn't
+Returns a C<Net::DNS::RR> object or C<undef> if the object could not
 be created.
 
 =head2 nxrrset
@@ -469,7 +462,7 @@ a dynamic update packet.
 
 Meaning:  No RRs with the specified name and type can exist.
 
-Returns a C<Net::DNS::RR> object or C<undef> if the object couldn't
+Returns a C<Net::DNS::RR> object or C<undef> if the object could not
 be created.
 
 =head2 yxdomain
@@ -481,7 +474,7 @@ update packet.
 
 Meaning:  At least one RR with the specified name must exist.
 
-Returns a C<Net::DNS::RR> object or C<undef> if the object couldn't
+Returns a C<Net::DNS::RR> object or C<undef> if the object could not
 be created.
 
 =head2 nxdomain
@@ -493,7 +486,7 @@ dynamic update packet.
 
 Meaning:  No RR with the specified name can exist.
 
-Returns a C<Net::DNS::RR> object or C<undef> if the object couldn't
+Returns a C<Net::DNS::RR> object or C<undef> if the object could not
 be created.
 
 =head2 rr_add
@@ -508,7 +501,7 @@ RR objects created by this method should be added to the "update"
 section of a dynamic update packet.  The TTL defaults to 86400
 seconds (24 hours) if not specified.
 
-Returns a C<Net::DNS::RR> object or C<undef> if the object couldn't
+Returns a C<Net::DNS::RR> object or C<undef> if the object could not
 be created.
 
 =head2 rr_del
@@ -534,7 +527,7 @@ Meaning:  Delete all RRs having the specified name, type, and data.
 RR objects created by this method should be added to the "update"
 section of a dynamic update packet.
 
-Returns a C<Net::DNS::RR> object or C<undef> if the object couldn't
+Returns a C<Net::DNS::RR> object or C<undef> if the object could not
 be created.
 
 
@@ -665,7 +658,7 @@ dynamic updates.
 	    print $rr->preference, " ", $rr->exchange, "\n";
 	}
     } else {
-	warn "Can't find MX records for $name: ", $res->errorstring, "\n";
+	warn "Can not find MX records for $name: ", $res->errorstring, "\n";
     }
 
 
